import React, { Component } from 'react';
import { connect } from 'react-redux';
import compose from 'recompose/compose';
import { withRouter } from 'react-router-dom';
import { getResources } from 'ra-core';
import { translate, DashboardMenuItem, MenuItemLink, Responsive } from 'react-admin';
import DefaultIcon from '@material-ui/icons/ViewList';
import DefaultSubMenuIcon from '@material-ui/icons/ChevronRight';

import SubMenu from './SubMenu';

class Menu extends Component {
    state = {};

    handleToggle(menu) {
        this.setState(state => ({ [`menu_${menu}`]: !state[`menu_${menu}`] }));
    }

    generateStructure() {
        const { resources } = this.props;
        var structure = [], i = -1;

        resources.forEach(res => {
            if (res.name.indexOf('_') > 0) {
                structure[i] = structure[i] && structure[i][0] ? [...structure[i], res] : [structure[i], res];
                structure[i].first = structure[i].first || structure[i][0];
            } else {
                structure[++i] = res;
            }
        });

        return structure;
    }

    render() {
        const { onMenuClick, open, logout } = this.props;
        const structure = this.generateStructure();
        return (
            <div>{' '}
                <DashboardMenuItem onClick={onMenuClick} />
                {structure.map((item, index) => (
                    item && item.first
                        ? (
                            <SubMenu
                                key={index}
                                handleToggle={() => this.handleToggle(item[0].name)}
                                isOpen={this.state[`menu_${item[0].name}`]}
                                sidebarIsOpen={open}
                                name={source2Label(item[0].name)}
                                icon={item.first.icon ? <item.first.icon /> : <DefaultSubMenuIcon />}>
                                {item.map(item => (
                                    <MenuItemLink
                                        key={item.name}
                                        to={`/${item.name}`}
                                        primaryText={source2Label(item.name)}
                                        onClick={onMenuClick}
                                        leftIcon={item.icon ? <item.icon /> : <DefaultIcon />} />
                                ))}
                            </SubMenu>
                        )
                        : (
                            <MenuItemLink
                                key={item.name}
                                to={`/${item.name}`}
                                primaryText={source2Label(item.name)}
                                onClick={onMenuClick}
                                leftIcon={item.icon ? <item.icon /> : <DefaultIcon />} />
                        )
                ))}
                <Responsive small={logout} medium={null} />
            </div>
        );
    }
}

const mapStateToProps = state => ({
    open: state.admin.ui.sidebarOpen,
    locale: state.i18n.locale,
    resources: getResources(state),
});

const enhance = compose(
    withRouter,
    connect(
        mapStateToProps,
        {}
    ),
    translate
);

const source2Label = source => source && (
    source[0].toUpperCase() + source.substring(1).split(/[_\-.]/).join(' ')
);

export const CustomMenu = Menu;

export default enhance(Menu);